# LaTexShortcuts

LaTex Shortcut is adds a couple of shortcuts that you can memorize to speed up your writing LaTex.

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install foobar.

```bash
pip install LaTexShortcuts
```

## Usage

```python LaTexShortcuts.py```
```python3 LaTexShortcuts.py```

## Contributing
Pull requests are welcome. For major changes, please open an issue first to discuss what you would like to change.

Please make sure to update tests as appropriate.

## License
[MIT](https://choosealicense.com/licenses/mit/)